Shortcuts

General Shortcuts

Shortcuts Description
ctrl-1 brings the score tab into focus
ctrl-2 brings the orchestra tab into focus
ctrl-3 brings the tables tab into focus
ctrl-4 brings the globals tab into focus
ctrl-5 brings the project properties tab into focus
ctrl-6 brings the soundfile tab into focus
alt-right brings the next manager tab into focus
alt-left brings the previous manager tab into focus
F9 start/stop a render (equivalent to pressing the render/stop button)
ctrl-g generate a CSD file
ctrl-shift-g generate a CSD to screen (for previewing)
ctrl-o open a work file
ctrl-s save work file (must use “Save as” from file menu if a new work file)
ctrl-w close the current work file
alt-F4 close Blue

Rendering

Shortcuts Description
F9 Render project using project’s real-time render options
shift-F9 Render to Disk and Play using project’s disk render options and playing with Blue’s builtin sound file player
ctrl-shift-F9 Render to Disk using project’s disk render options
spacebar Render project using project’s real-time render options when Score is in focus

Score Timeline

Shortcuts Description
spacebar Render project using the project’s real-time render options
1 Switch to Score mode
2 Switch to Single Line mode
3 Switch to Multi Line mode
alt-s Toggle snap on or off
g Scroll the score view to the render start time
y Scroll the score view to the render end time
[ Move render start time to the previous marker or project start
] Move render start time to the next marker or project end
ctrl-c Copy selected score objects
ctrl-x Cut selected score objects
ctrl-z Undo
ctrl-shift-z Redo
delete / backspace Remove selected score objects
ctrl-d Duplicate selected score objects and place the copies immediately after the originals
ctrl-r Repeat selected score objects by entering a repeat count
ctrl-click Paste copied score objects at the clicked time
shift-click Add or remove a score object from the current selection
ctrl-t Open the Quick Time dialog for the selected score object
f3 Open the Sound Object Properties window
right click Open the context menu for the item under the pointer
left click + drag Create a marquee selection in Score mode
left Nudge selected score objects one pixel to the left
right Nudge selected score objects one pixel to the right
shift-left Nudge selected score objects ten pixels to the left
shift-right Nudge selected score objects ten pixels to the right
up Move selected score objects up one layer
down Move selected score objects down one layer
ctrl-left Decrease horizontal zoom
ctrl-right Increase horizontal zoom

When a layer-header panel has focus, up and down move the layer selection within that panel, and shift-up / shift-down extend the selection.

Audio Layer Groups

Shortcuts Description
shift-alt-click Split the Audio Clip at the clicked point
alt-drag Move the audio content within the Audio Clip without moving the clip start

Orchestra Manager

Shortcuts Description
ctrl-left click if on the column header of the instruments table, will enable/disable all instruments

In a text box

Shortcuts Description
right click pops up a popup menu that contains entries for opcodes as well as user-defined entries from the code repository
ctrl-space brings up a dialog that shows all possible opcode matches for the current word being typed in (code completion)
shift-F1 if cursor is within a word that is an opcode, attempts to look up manual entry for that opcode
shift-F2 if cursor is within a word that is an opcode, attempts to find a manual example CSD for that opcode and if found opens a dialog showing the example
ctrl-; comment out line or selected lines (prepends “;” to every line)
ctrl-shift-; uncomment out line or selected lines (removes “;” at beginning of every line if found)

Editing GenericScore, PythonObject, JavaScriptObject

Shortcuts Description
ctrl-T when the text area is focused, ctrl-T runs test on the soundObject (same as pressing the test button)